<div align="center">
  <img width="540" align="center" src="https://i.imgur.com/YGRalOv.png">
  <p><b>JavaScript API bindings for <a href="https://audius.co">Audius</a>.</b></p>
  <p>Need help? Join the support server!: <a href="https://discord.gg/VBDhRc8">https://discord.gg/VBDhRc8/</a></p>
  <a href="https://nodei.co/npm/audius/"><img src="https://nodei.co/npm/audius.png"></a><br>
  <img alt="npm" src="https://img.shields.io/npm/dw/audius">
  <img alt="npm" src="https://img.shields.io/npm/dt/audius">
</div>

<h1>Basic Usage</h1>

```js
const Audius = require('audius')
// The app name is requested by Audius. It is not required but strongly encouraged.
// The API is open and no key is required.
const audiusApp = new Audius("My Cool App v1.0.2")

// Searching for a user
audiusApp.searchUsers('Skrillex').then(users => {
  // Provided Skrillex was the first in the list, would print "Hey, Skrillex!"
  console.log("Hey,", users[0].name + "!" )
})
```

<h1>Methods</h1>
All methods return promises, and are JSDoc documented, so be sure to use a modern editor such as Visual Studio Code to easily view 

| Name                                                  	| Description                                	| Parameters                                                                                                                                                                                                         	| Returns    	|
|-------------------------------------------------------	|--------------------------------------------	|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------	|-------------	|
| Audius#searchUsers(search: String)                    	| Find users by name.                        	| search: The search term to find users by.                                                                                                                                                                          	| User[]      	|
| Audius#searchTracks(search: String)                   	| Find tracks by name.                       	| search: The search term to find tracks by.                                                                                                                                                                         	| Track[]     	|
| Audius#searchPlaylists(search: String)                	| Find playlists by name.                    	| search: The search term to find playlists by.                                                                                                                                                                      	| Playlist[]  	|
| Audius#getTrack(id: String)                           	| Retrieve a track by ID.                    	| id: The unique ID of the track.                                                                                                                                                                                    	| Track       	|
| Audius#getUser(id: String)                            	| Retrieve a user by ID.                     	| id: The unique ID of the user.                                                                                                                                                                                     	| User        	|
| Audius#getPlaylist(id: String)                        	| Retrieve a playlist by ID.                 	| id: The unique ID of the playlist.                                                                                                                                                                                 	| Playlist    	|
| Audius#getTrendingTracks(time: String, genre: String) 	| Get the top 100 trending tracks on Audius. 	| time: The time range of which to get trending tracks. Either "week", "month" or "allTime". If blank, defaults to "week".<br>genre: The genre of which to get trending tracks for. If blank, defaults to any genre. 	| Track[]     	|
| Audius#getPlaylistTracks(id: String)                  	| Get the tracks of a playlist by ID.        	| id: The unique ID of the playlist.                                                                                                                                                                                 	| Track[]     	|
| Audius#getUserTracks(id: String)                      	| Get the tracks uploaded by a user by ID.   	| id: The unique ID of the user.                                                                                                                                                                                     	| Track[]     	|
| Audius#getUserFavourites(id: String)                  	| Get the favourites of a user by ID.        	| id: The unique ID of the user.                                                                                                                                                                                     	| Favourite[] 	|

<h1>Structures</h1>

| Name       	| Description                                                                                                        	| Properties                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      	|
|------------	|--------------------------------------------------------------------------------------------------------------------	|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------	|
| User       	| A user profile.                                                                                                    	| albumCount: The number of albums this user has published.<br>bio: The bio of the user.<br>coverPhoto: A CoverPhoto containing three sizes of cover photo.<br>following: The number of accounts this user is following.<br>followers: The number of users that are following this account.<br>handle: The permanent name of the user.<br>id: The unique ID of the user.<br>verified: Whether the user is verified or not.<br>location: The location set on the user's profile.<br>name: The customisable name on the user's profile.<br>playlistCount: The number of playlists the user has published.<br>profilePicture: An Artwork containing three sizes of profile picture.<br>repostCount: The number of tracks the user has reposted.<br>trackCount: The number of original tracks the user has published. 	|
| Track      	| A music track.                                                                                                     	| artwork: An Artwork object containing links to three different sizes of artwork.<br>description: The track's description.<br>genre: The genre of the track.<br>id: The unique ID of the track.<br>mood: The mood of the track.<br>releaseDate: The release date of the track.<br>remixOf: The original track the track remixes, if any.<br>repostCount: The number of times the track has been reposted.<br>favouriteCount: The number of times the track has been favourited.<br>playCount: The number of times the track has been played.<br>tags: The track's tags that define its content.<br>title: The title of the track.<br>user: The user that uploaded the track.<br>duration: The length of the track in seconds.<br>downloadable: Whether or not the track is downloadable.                         	|
| Playlist   	| A playlist or album of multiple tracks.                                                                            	| artwork: An Artwork object containing links to three different sizes of artwork.<br>description: The description of the playlist.<br>id: The unique ID of the playlist.<br>isAlbum: Whether the playlist is an album or not.<br>name: The name of the playlist.<br>repostCount: The number of times the playlist has been reposted.<br>favouriteCount: The number of times the playlist has been favourited.<br>totalPlayCount: The total number of track plays in the playlist.<br>user: The user that made the playlist.                                                                                                                                                                                                                                                                                      	|
| Artwork    	| A piece of artwork shown on a track, playlist or profile picture.                                                  	| small: The small 100x100 artwork.<br>medium: The medium 480x480 artwork.<br>large: The large 1000x1000 artwork.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 	|
| CoverPhoto 	| A cover photo on a user profile.                                                                                   	| small: The small 640x640 cover photo.<br>large: The large 2000x2000 cover photo.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                	|
| Favourite  	| A favourited item, such as a track. Does not contain the item itself, only the link between the user and the item. 	| id: The unique ID of the favourite.<br>type: The type of Item this favourite is.<br>userID: The unique ID of the user that made this favourite.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 	|

<h1>Roadmap</h1>
Being 100% feature-complete with the API is the main goal.<br>
The current milestone to reach is streaming tracks. This may take a while so I've decided to release the main API bindings in the mean time whilst I work on it.